@@ -64,8 +64,8 @@ BookWidget::BookWidget(TQWidget *parent, const char *name)
 	setWFlags(TQt::WNoAutoErase);
 	setFocusPolicy(TQWidget::StrongFocus);
 	
-	connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(loadLine()));
-	connect(m_renderer.get(), TQT_SIGNAL(renderingFinished()), this, TQT_SLOT(renderingFinished()));
+	connect(&m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(loadLine()));
+	connect(m_renderer.get(), TQ_SIGNAL(renderingFinished()), this, TQ_SLOT(renderingFinished()));
 }
 
 
@@ -92,7 +92,7 @@ void BookWidget::openURL(const KURL & url)
 	m_progressDlg->setLabel("Loading file " + m_url.path());
 	m_progressDlg->setAllowCancel(true);
 	m_progressDlg->progressBar()->setTotalSteps(0);
-	connect(m_progressDlg.get(), TQT_SIGNAL(cancelClicked()), TQT_SLOT(cancelLoading()));
+	connect(m_progressDlg.get(), TQ_SIGNAL(cancelClicked()), TQ_SLOT(cancelLoading()));
 	KDialog::centerOnScreen(m_progressDlg.get());
  	m_progressDlg->show();
 	//start timer for processing gui events
@@ -155,7 +155,7 @@ void BookWidget::drawBookmark(TQPainter & paint, Bookmark const& bm)
 		paint.save();
 		paint.translate(TQWidget::width()/2., 20.);
 		paint.rotate(90.);
-		const TQString text = bm.name() + " (" + bm.dateTime().toString(Qt::LocalDate) + ")";
+		const TQString text = bm.name() + " (" + bm.dateTime().toString(TQt::LocalDate) + ")";
 		paint.drawText(0, 0, text);
 		paint.restore();
 	}
@@ -222,7 +222,7 @@ void BookWidget::setupPageSize()
 
 void BookWidget::mousePressEvent(TQMouseEvent * event)
 {
-	if (event->button() == Qt::LeftButton)
+	if (event->button() == TQt::LeftButton)
 	{
 		if (rectLeftPage().contains(event->pos()))
 		{
@@ -366,9 +366,9 @@ void BookWidget::loadLine()
 	//setup and show
 	firstPage();
 	//clean up
-	m_progressDlg.reset(0);
-	m_stream.reset(0);
-	m_textLines.reset(0);
+	m_progressDlg.reset();
+	m_stream.reset();
+	m_textLines.reset();
 	m_file.close();
 	m_modified = true;
 	emit loadingFinished();
@@ -378,15 +378,15 @@ void BookWidget::cancelLoading()
 {
 	m_timer.stop();
 	if (parentWidget())
-		TQT_TQWIDGET(parentWidget())->setCaption("");
- 	//clean up
- 	m_progressDlg->hide();
- 	m_stream.reset(0);
- 	m_textLines.reset(0);
- 	m_file.close();
- 	//setup and show
- 	m_renderer->clear();
- 	firstPage();
+		parentWidget()->setCaption("");
+	//clean up
+	m_progressDlg->hide();
+	m_stream.reset();
+	m_textLines.reset();
+	m_file.close();
+	//setup and show
+	m_renderer->clear();
+	firstPage();
 }
 
 void BookWidget::setParaOffset(int offset)
@@ -429,7 +429,7 @@ void BookWidget::saveBookmarks( )
 	for (Bookmarks::size_type i = 0; i < m_bookmarks.size(); ++i)
 	{
 		const Bookmark & bm = m_bookmarks[i];
-		config.setGroup(tqtr("Bookmark %1").arg(i));
+		config.setGroup(tr("Bookmark %1").arg(i));
 		config.writeEntry("page", bm.page());
 		config.writeEntry("name", bm.name());
 		config.writeEntry("dateTime", bm.dateTime());
